httpcommon

package module
v0.0.0-...-c9f467a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PathRedirect

func PathRedirect(r *http.Request) string

Returns a string containing URL-escaped value of the path query parameter or current endpoint path

func RedirectGetPath

func RedirectGetPath(w http.ResponseWriter, r *http.Request)

Redirects to path query parameter. Can only redirect in the same host (to prevent security issues)

func RedirectRoot

func RedirectRoot(w http.ResponseWriter, r *http.Request)

Redirects to the website root path, preserving the "path" query parameter

func Refresh

func Refresh(w http.ResponseWriter, r *http.Request)

Refreshes the website by redirecting to current request URI

Types

This section is empty.

Jump to