Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PathRedirect ¶
Returns a string containing URL-escaped value of the path query parameter or current endpoint path
func RedirectGetPath ¶
func RedirectGetPath(w http.ResponseWriter, r *http.Request)
Redirects to path query parameter. Can only redirect in the same host (to prevent security issues)
func RedirectRoot ¶
func RedirectRoot(w http.ResponseWriter, r *http.Request)
Redirects to the website root path, preserving the "path" query parameter
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.